==> nextalarm_0.1.6.tar.gz: nextalarm-0.1.6/nextalarm_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="59"/>
        <source>alarms in next %1 h</source>
        <translation>Alarme dans les %1 heures</translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="166"/>
        <source>--:--</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation>Paramètres de Next Alarm</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="32"/>
        <source>Lines</source>
        <translation>Lignes</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="52"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="79"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="109"/>
        <source>B</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="127"/>
        <source>I</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="134"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="141"/>
        <source>12:48</source>
        <translation></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="154"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="180"/>
        <source>Only std Alarms</source>
        <translation>Seulement les alarmes standards</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="187"/>
        <source>TimeRemain</source>
        <translation>Temps restant</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="194"/>
        <source>Header</source>
        <translation>Entête</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="201"/>
        <source>Alarm Title</source>
        <translation>Titre de l&apos;alarme</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="214"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="221"/>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="102"/>
        <source>About Next Alarm</source>
        <translation>A propos de Next Alarm</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="103"/>
        <source>&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.6&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing time of next alarm</source>
        <translation>&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.6Utilise &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Widget, qui affiche l&apos;heure des prochaines alarmes</translation>
    </message>
</context>
</TS>

==> nextalarm_0.2.0.tar.gz: nextalarm-0.2.0/nextalarm_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="59"/>
        <source>alarms in next %1 h</source>
        <translation>Alarme dans les %1 heures</translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="166"/>
        <source>--:--</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation>Paramètres de &quot;Next Alarm&quot;</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="32"/>
        <source>Lines</source>
        <translation>Lignes</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="52"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="79"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="109"/>
        <source>B</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="127"/>
        <source>I</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="134"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="141"/>
        <source>12:48</source>
        <translation></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="154"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="180"/>
        <source>Only std Alarms</source>
        <translation>Alarmes standards</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="187"/>
        <source>TimeRemain</source>
        <translation>Temps restant</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="194"/>
        <source>Header</source>
        <translation>Afficher l&apos;entête</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="201"/>
        <source>Alarm Title</source>
        <translation>Titre de l&apos;alarme</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="214"/>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="221"/>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="102"/>
        <source>About Next Alarm</source>
        <translation>A propos de &quot;Next Alarm&quot;</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="103"/>
        <source>&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.5&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing time of next alarm</source>
        <translation>&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.5&lt;br&gt;Utilise &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Widget, qui affiche l&apos;heure des prochaines alarmes&lt;br&gt;&lt;br&gt;Traduction: GaRy delaMer</translation>
    </message>
</context>
</TS>
